@@ -55,7 +55,7 @@ import org.openide.ErrorManager;
 
 
 public class RADVisualContainer extends RADVisualComponent implements ComponentContainer {
-    private ArrayList<RADVisualComponent> subComponents = new ArrayList(10);
+    private ArrayList<RADVisualComponent> subComponents = new ArrayList<RADVisualComponent>(10);
     private LayoutSupportManager layoutSupport; // = new LayoutSupportManager();
     private LayoutNode layoutNode; // [move to LayoutSupportManager?]
 
@@ -65,19 +65,9 @@ public class RADVisualContainer extends RADVisualComponent implements ComponentC
     private boolean noContainerDelegate;
 
     private static Map<MenuType, Class[]> supportedMenus;
-//    public boolean initialize(FormModel formModel) {
-//        if (super.initialize(formModel)) {
-//            if (getBeanClass() != null)
-//                layoutSupport.initialize(this, formModel.getCodeStructure());
-//            return true;
-//        }
-//        return false;
-//    }
 
+    @Override
     protected void setBeanInstance(Object beanInstance) {
-//        if (layoutSupport != null && layoutSupport.getLayoutDelegate() != null)
-//            layoutSupport.clearPrimaryContainer();
-
         containerDelegateGetter = null;
         noContainerDelegate = false;
 
@@ -87,6 +77,7 @@ public class RADVisualContainer extends RADVisualComponent implements ComponentC
             layoutSupport = new LayoutSupportManager(this, getFormModel().getCodeStructure());
     }
 
+    @Override
     void setInModel(boolean in) {
         boolean alreadyIn = isInModel();
         super.setInModel(in);
@@ -157,7 +148,9 @@ public class RADVisualContainer extends RADVisualComponent implements ComponentC
     private void refillContainerInstance() {
         Container cont = getContainerDelegate(getBeanInstance());
         cont.removeAll();
-        cont.setLayout(null); // Issue 77904
+        if (!(cont instanceof ScrollPane)) { // Issue 128797
+            cont.setLayout(null); // Issue 77904
+        }
         for (RADVisualComponent sub : subComponents) {
             Component comp = (Component) sub.getBeanInstance();
             FakePeerSupport.attachFakePeer(comp);
@@ -167,19 +160,15 @@ public class RADVisualContainer extends RADVisualComponent implements ComponentC
         }
     }
 
-//    public boolean hasOldLayoutSupport() {
-//        return layoutSupport != null;
-//    }
-
     public boolean hasDedicatedLayoutSupport() {
         return layoutSupport != null && layoutSupport.isDedicated();
     }
 
     /**
+     * @param container container.
      * @return The JavaBean visual container represented by this
      * RADVisualComponent
      */
-    
     public Container getContainerDelegate(Object container) {
         if (container instanceof RootPaneContainer
                 && container.getClass().getName().startsWith("javax.swing.")) // NOI18N
@@ -188,14 +177,23 @@ public class RADVisualContainer extends RADVisualComponent implements ComponentC
             return ((JRootPane)container).getContentPane();
 
         Container containerDelegate = (Container) container;
-        Method m = getContainerDelegateMethod();
-        if (m != null) {
-            try {
-                containerDelegate =
-                    (Container) m.invoke(container, new Object[0]);
-            }
-            catch (Exception ex) {
-                org.openide.ErrorManager.getDefault().notify(org.openide.ErrorManager.INFORMATIONAL, ex);
+        // Do not attempt to find container delegate if the classes
+        // don't match. This can happen when ViewConverter was used.
+        // Happens for JApplet, for example.
+        if (getBeanClass().isAssignableFrom(container.getClass())) {
+            Method m = getContainerDelegateMethod();
+            if (m != null) {
+                try {
+                    containerDelegate = (Container) m.invoke(container, new Object[0]);
+                    if ((containerDelegate == null) && (container instanceof JScrollPane)) {
+                        JScrollPane scrollPane = (JScrollPane)container;
+                        scrollPane.setViewportView(null); // force recreation of viewport
+                        containerDelegate = (Container) m.invoke(container, new Object[0]);
+                    }
+                }
+                catch (Exception ex) {
+                    org.openide.ErrorManager.getDefault().notify(org.openide.ErrorManager.INFORMATIONAL, ex);
+                }
             }
         }
         return containerDelegate;
@@ -255,7 +253,7 @@ public class RADVisualContainer extends RADVisualComponent implements ComponentC
             // this is a menu container accepting certain types of menus
             Class[] possibleClasses = getPossibleSubmenus(getMenuType(getBeanClass()));
             if (possibleClasses != null) {
-                for (Class cls : possibleClasses) {
+                for (Class<?> cls : possibleClasses) {
                     if (cls.isAssignableFrom(compClass)) {
                         return true;
                     }
@@ -272,7 +270,8 @@ public class RADVisualContainer extends RADVisualComponent implements ComponentC
             // visual component can be added to visual container
             // exception: avoid adding components to scroll pane that already contains something
             if (JScrollPane.class.isAssignableFrom(getBeanClass())
-                    && ((JScrollPane)getBeanInstance()).getViewport().getView() != null) {
+                    && (((JScrollPane)getBeanInstance()).getViewport() != null)
+                    && (((JScrollPane)getBeanInstance()).getViewport().getView() != null)) {
                 return false;
             }
             return true;
@@ -320,7 +319,7 @@ public class RADVisualContainer extends RADVisualComponent implements ComponentC
     }
 
     public RADVisualComponent getSubComponent(int index) {
-        return (RADVisualComponent) subComponents.get(index);
+        return subComponents.get(index);
     }
 
     // the following methods implement ComponentContainer interface
@@ -341,7 +340,7 @@ public class RADVisualContainer extends RADVisualComponent implements ComponentC
 
     public void initSubComponents(RADComponent[] initComponents) {
         if (subComponents == null)
-            subComponents = new ArrayList(initComponents.length);
+            subComponents = new ArrayList<RADVisualComponent>(initComponents.length);
         else {
             subComponents.clear();
             subComponents.ensureCapacity(initComponents.length);
