@@ -102,7 +102,7 @@ public class JWSCustomizerPanel extends JPanel implements HelpCtx.Provider {
      * WARNING: Do NOT modify this code. The content of this method is
      * always regenerated by the Form Editor.
      */
-    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
+    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
     private void initComponents() {
         java.awt.GridBagConstraints gridBagConstraints;
 
@@ -112,6 +112,7 @@ public class JWSCustomizerPanel extends JPanel implements HelpCtx.Provider {
         iconTextField = new javax.swing.JTextField();
         browseButton = new javax.swing.JButton();
         codebaseComboBox = new javax.swing.JComboBox();
+        codeBaseValueLabel = new javax.swing.JLabel();
         codebaseTextField = new javax.swing.JTextField();
         offlineCheckBox = new javax.swing.JCheckBox();
         panelDescLabel = new javax.swing.JLabel();
@@ -200,6 +201,17 @@ public class JWSCustomizerPanel extends JPanel implements HelpCtx.Provider {
         codebaseComboBox.getAccessibleContext().setAccessibleName(org.openide.util.NbBundle.getMessage(JWSCustomizerPanel.class, "ACSN_Codebase_Combobox")); // NOI18N
         codebaseComboBox.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(JWSCustomizerPanel.class, "ACSD_Codebase_Combobox")); // NOI18N
 
+        codeBaseValueLabel.setLabelFor(codebaseTextField);
+        org.openide.awt.Mnemonics.setLocalizedText(codeBaseValueLabel, org.openide.util.NbBundle.getMessage(JWSCustomizerPanel.class, "JWSCustomizerPanel.codeBaseValueLabel.text" )); // NOI18N
+        gridBagConstraints = new java.awt.GridBagConstraints();
+        gridBagConstraints.gridx = 0;
+        gridBagConstraints.gridy = 4;
+        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
+        gridBagConstraints.insets = new java.awt.Insets(8, 0, 0, 0);
+        add(codeBaseValueLabel, gridBagConstraints);
+        codeBaseValueLabel.getAccessibleContext().setAccessibleName(org.openide.util.NbBundle.getMessage(JWSCustomizerPanel.class, "ACSN_Codebase_Result_Label" )); // NOI18N
+        codeBaseValueLabel.getAccessibleContext().setAccessibleDescription(org.openide.util.NbBundle.getMessage(JWSCustomizerPanel.class, "ACSD_Codebase_Result_Label" )); // NOI18N
+
         gridBagConstraints = new java.awt.GridBagConstraints();
         gridBagConstraints.gridx = 1;
         gridBagConstraints.gridy = 4;
@@ -342,6 +354,7 @@ public class JWSCustomizerPanel extends JPanel implements HelpCtx.Provider {
     
     // Variables declaration - do not modify//GEN-BEGIN:variables
     private javax.swing.JButton browseButton;
+    private javax.swing.JLabel codeBaseValueLabel;
     private javax.swing.JComboBox codebaseComboBox;
     private javax.swing.JLabel codebaseLabel;
     private javax.swing.JTextField codebaseTextField;
