@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2008 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -24,7 +24,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2008 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -109,13 +109,13 @@ final class BasicSearchForm extends JPanel implements ChangeListener,
     
     private final BasicSearchCriteria searchCriteria;
     private final Map<SearchScope, Boolean> searchScopes;
-    private final SearchScope preferredSearchScope;
+    private final String preferredSearchScopeType;
     private SearchScope selectedSearchScope;
     private ChangeListener usabilityChangeListener;
         
     /** Creates new form BasicSearchForm */
     BasicSearchForm(Map<SearchScope, Boolean> searchScopes,
-                    SearchScope preferredSearchScope,
+                    String preferredSearchScopeType,
 		    BasicSearchCriteria criteria,
 		    boolean searchAndReplace,
                     boolean usePreviousValues) {
@@ -123,7 +123,7 @@ final class BasicSearchForm extends JPanel implements ChangeListener,
                               ? criteria
                               : new BasicSearchCriteria();
         this.searchScopes = searchScopes;
-        this.preferredSearchScope = preferredSearchScope;
+        this.preferredSearchScopeType = preferredSearchScopeType;
         initComponents(searchAndReplace);
         initAccessibility();
         initHistory();
@@ -434,33 +434,15 @@ final class BasicSearchForm extends JPanel implements ChangeListener,
             }
         }
 
-        /**
-         * Listener that selects all text in a text field when the text field
-         * gains permanent focus.
-         */
-        class TextFieldFocusListener implements FocusListener {
-
-            public void focusGained(FocusEvent e) {
-                if (!e.isTemporary()) {
-                    JTextComponent textComp = (JTextComponent) e.getSource();
-                    if (textComp.getText().length() != 0) {
-                        textComp.selectAll();
-                    }
-                }
-            }
-
-            public void focusLost(FocusEvent e) {
-                /* do nothing */
-            }
-
-        }
-
         final TextFieldFocusListener focusListener = new TextFieldFocusListener();
         textToFindEditor.addFocusListener(focusListener);
-        fileNamePatternEditor.addFocusListener(focusListener);
         if (replacementPatternEditor != null) {
             replacementPatternEditor.addFocusListener(focusListener);
         }
+
+        final FileNamePatternWatcher watcher = new FileNamePatternWatcher(fileNamePatternEditor);
+        fileNamePatternEditor.addFocusListener(watcher);
+        fileNamePatternEditor.addHierarchyListener(watcher);
         
         textToFindEditor.getDocument().addDocumentListener(
                 new PatternChangeListener(cboxTextToFind));
@@ -477,9 +459,6 @@ final class BasicSearchForm extends JPanel implements ChangeListener,
             replacementPatternEditor.addKeyListener(this);
         }
 
-        /* display "(all files)" if no file name pattern is specified: */
-        FileNamePatternWatcher.setUpFor(this, fileNamePatternEditor);
-
         chkRegexp.addItemListener(this);
         chkCaseSensitive.addItemListener(this);
         chkWholeWords.addItemListener(this);
@@ -676,7 +655,9 @@ final class BasicSearchForm extends JPanel implements ChangeListener,
         int firstEnabled = -1;
         for (Map.Entry<SearchScope, Boolean> entry : orderSearchScopes()) {
             SearchScope searchScope = entry.getKey();
-            String searchScopeInfo = searchScope.getAdditionalInfo();
+            boolean enabled = entry.getValue();
+            String searchScopeInfo = enabled ? searchScope.getAdditionalInfo()
+                                             : null;
             AbstractButton button = (searchScopeInfo == null)
                                     ? new JRadioButton()
                                     : new ButtonWithExtraInfo(searchScopeInfo);
@@ -685,10 +666,9 @@ final class BasicSearchForm extends JPanel implements ChangeListener,
             button.putClientProperty("searchScope", searchScope);
             button.addItemListener(buttonStateListener);
 
-            boolean enabled = entry.getValue();
             button.setEnabled(enabled);
             if (enabled) {
-                if (searchScope == preferredSearchScope) {
+                if (searchScope.getTypeId().equals(preferredSearchScopeType)) {
                     button.setSelected(true);
                     preferredScopeSelected = true;
                 } else if (firstEnabled == -1) {
@@ -844,26 +824,39 @@ final class BasicSearchForm extends JPanel implements ChangeListener,
     }
     
     /**
-     * Class that watches how the File Name Patterns combo-box is focused
-     * and text inside it modified and displays an information text in it
-     * if no pattern is specified and the combo-box is not focused.
+     * Listener that selects all text in a text field when the text field
+     * gains permanent focus.
+     */
+    private static class TextFieldFocusListener implements FocusListener {
+
+        public void focusGained(FocusEvent e) {
+            if (!e.isTemporary()) {
+                JTextComponent textComp = (JTextComponent) e.getSource();
+                if (textComp.getText().length() != 0) {
+                    textComp.selectAll();
+                }
+            }
+        }
+
+        public void focusLost(FocusEvent e) {
+            /* do nothing */
+        }
+
+    }
+
+    /**
+     * Extension of the {@code TextFieldFocusListener}
+     * - besides selecting of all text upon focus gain,
+     * it displays &quot;(no files)&quot; if no file name pattern is specified.
      * 
      * @author  Marian Petras
      */
-    private static final class FileNamePatternWatcher
-                                implements HierarchyListener, FocusListener {
-        
-        private static void setUpFor(BasicSearchForm form,
-                                     JTextComponent txtComp) {
-            FileNamePatternWatcher watcher = new FileNamePatternWatcher(form, txtComp);
-            txtComp.addFocusListener(watcher);
-            txtComp.addHierarchyListener(watcher);
-        }
+    private final class FileNamePatternWatcher extends TextFieldFocusListener
+                                               implements HierarchyListener {
         
         private final Logger watcherLogger = Logger.getLogger(
                 "org.netbeans.modules.search.BasicSearchForm.FileNamePatternWatcher");//NOI18N
         
-        private final BasicSearchForm form;
         private final JTextComponent txtComp;
         private final Document doc;
         
@@ -871,9 +864,7 @@ final class BasicSearchForm extends JPanel implements ChangeListener,
         private String infoText;
         private boolean infoDisplayed;
         
-        private FileNamePatternWatcher(BasicSearchForm form,
-                                       JTextComponent txtComp) {
-            this.form = form;
+        private FileNamePatternWatcher(JTextComponent txtComp) {
             this.txtComp = txtComp;
             doc = txtComp.getDocument();
         }
@@ -894,13 +885,23 @@ final class BasicSearchForm extends JPanel implements ChangeListener,
             }
         }
         
+        @Override
         public void focusGained(FocusEvent e) {
+
+            /*
+             * Order of method calls hideInfo() and super.focusGained(e)
+             * is important! See bug #113202.
+             */
+
             if (infoDisplayed) {
                 hideInfo();
             }
+            super.focusGained(e);   //selects all text
         }
 
+        @Override
         public void focusLost(FocusEvent e) {
+            super.focusLost(e);     //does nothing
             if (isEmptyText()) {
                 displayInfo();
             }
@@ -929,12 +930,12 @@ final class BasicSearchForm extends JPanel implements ChangeListener,
             try {
                 txtComp.setForeground(txtComp.getDisabledTextColor());
                 
-                form.ignoreFileNamePatternChanges = true;
+                ignoreFileNamePatternChanges = true;
                 doc.insertString(0, getInfoText(), null);
             } catch (BadLocationException ex) {
                 Exceptions.printStackTrace(ex);
             } finally {
-                form.ignoreFileNamePatternChanges = false;
+                ignoreFileNamePatternChanges = false;
                 infoDisplayed = true;
             }
         }
@@ -944,12 +945,12 @@ final class BasicSearchForm extends JPanel implements ChangeListener,
             
             txtComp.setEnabled(true);
             try {
-                form.ignoreFileNamePatternChanges = true;
+                ignoreFileNamePatternChanges = true;
                 doc.remove(0, doc.getLength());
             } catch (BadLocationException ex) {
                 Exceptions.printStackTrace(ex);
             } finally {
-                form.ignoreFileNamePatternChanges = false;
+                ignoreFileNamePatternChanges = false;
                 txtComp.setForeground(foregroundColor);
                 infoDisplayed = false;
             }
