@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2008 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -24,7 +24,7 @@
  * Contributor(s):
  *
  * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
+ * Software is Sun Microsystems, Inc. Portions Copyright 1997-2008 Sun
  * Microsystems, Inc. All Rights Reserved.
  *
  * If you wish your version of this file to be governed by only the CDDL
@@ -44,6 +44,7 @@ package org.netbeans.modules.search;
 import java.awt.Component;
 import java.awt.EventQueue;
 import java.awt.event.ActionEvent;
+import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyChangeSupport;
 import java.lang.ref.Reference;
@@ -64,7 +65,6 @@ import org.openide.util.actions.CallableSystemAction;
 import org.openide.util.HelpCtx;
 import org.openide.util.NbBundle;
 import org.openide.util.actions.Presenter;
-import org.openide.util.actions.SystemAction;
 import org.openidex.search.SearchType;
 import static java.util.logging.Level.FINER;
 
@@ -311,7 +311,7 @@ public class FindInFilesAction extends CallableSystemAction
     }
 
     private void performAction(Map<SearchScope, Boolean> searchScopes,
-                               SearchScope preferredSearchScope) {
+                               String preferredSearchScopeType) {
         assert EventQueue.isDispatchThread();
 
         String msg = Manager.getInstance().mayStartSearching();
@@ -333,7 +333,7 @@ public class FindInFilesAction extends CallableSystemAction
 
         boolean replacing = Boolean.TRUE.equals(getProperty(REPLACING));
         SearchPanel searchPanel = new SearchPanel(searchScopes,
-                                                  preferredSearchScope,
+                                                  preferredSearchScopeType,
                                                   replacing);
         
         searchPanel.showDialog();
@@ -346,7 +346,7 @@ public class FindInFilesAction extends CallableSystemAction
 	List<SearchType> extraSearchTypes = searchPanel.getSearchTypes();
         
         ResultView resultView = ResultView.getInstance();
-        resultView.rememberInput(searchScope,
+        resultView.rememberInput(searchScope.getTypeId(),
 			         basicSearchCriteria,
 				 extraSearchTypes);
         resultView.open();
@@ -434,7 +434,7 @@ public class FindInFilesAction extends CallableSystemAction
             delegate.performAction(
                     searchScopeRegistry.getSearchScopes(),
                     searchSelection
-                        ? searchScopeRegistry.getNodeSelectionSearchScope()
+                        ? searchScopeRegistry.getNodeSelectionSearchScope().getTypeId()
                         : null);
         }
 
@@ -508,13 +508,21 @@ public class FindInFilesAction extends CallableSystemAction
 
             synchronized (getLock()) {
                 if (support != null) {
-                    final boolean wasEnabled = enabled;
-                    final boolean newEnabled = searchScopeRegistry.hasApplicableSearchScope();
-                    enabled = newEnabled;
+
+                    boolean wasEnabled = enabled;
+                    enabled = searchScopeRegistry.hasApplicableSearchScope();
+
+                    /* notify the listeners: */
+                    final PropertyChangeEvent newEvent
+                            = new PropertyChangeEvent(this, PROP_ENABLED,
+                                                      wasEnabled, enabled);
+                    final PropertyChangeListener[] listeners
+                            = support.getPropertyChangeListeners();
                     Mutex.EVENT.writeAccess(new Runnable() {
                         public void run() {
-                            support.firePropertyChange(SystemAction.PROP_ENABLED,
-                                                       wasEnabled, newEnabled);
+                            for (PropertyChangeListener l : listeners) {
+                                l.propertyChange(newEvent);
+                            }
                         }
                     });
                 }
